@@ -13,7 +13,6 @@
 # limitations under the License.
 
 from langchain_community.document_loaders import (
-    UnstructuredMarkdownLoader,
     AirbyteJSONLoader, UnstructuredHTMLLoader,
     PythonLoader)
 
@@ -25,70 +24,89 @@ from .AlitaJSONLoader import AlitaJSONLoader
 from .AlitaPDFLoader import AlitaPDFLoader
 from .AlitaPowerPointLoader import AlitaPowerPointLoader
 from .AlitaTextLoader import AlitaTextLoader
+from .AlitaMarkdownLoader import AlitaMarkdownLoader
+from .AlitaPythonLoader import AlitaPythonLoader
+from enum import Enum
+
+class LoaderProperties(Enum):
+    LLM = 'llm'
+    PROMPT = 'prompt'
+    PROMPT_DEFAULT = 'prompt_default'
 
 loaders_map = {
     '.png': {
         'class': AlitaImageLoader,
         'is_multimodal_processing': True,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value],
     },
     '.jpg': {
         'class': AlitaImageLoader,
         'is_multimodal_processing': True,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.jpeg': {
         'class': AlitaImageLoader,
         'is_multimodal_processing': True,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.gif': {
         'class': AlitaImageLoader,
         'is_multimodal_processing': True,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.bmp': {
         'class': AlitaImageLoader,
         'is_multimodal_processing': True,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.svg': {
         'class': AlitaImageLoader,
         'is_multimodal_processing': True,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.txt': {
         'class': AlitaTextLoader,
         'is_multimodal_processing': False,
         'kwargs': {
             'autodetect_encoding': True
-        }
+        },
+        'allowed_to_override': ['max_tokens']
     },
     '.yml': {
         'class': AlitaTextLoader,
         'is_multimodal_processing': False,
         'kwargs': {
             'autodetect_encoding': True
-        }
+        },
+        'allowed_to_override': ['max_tokens']
     },
     '.yaml': {
         'class': AlitaTextLoader,
         'is_multimodal_processing': False,
         'kwargs': {
             'autodetect_encoding': True
-        }
+        },
+        'allowed_to_override': ['max_tokens']
     },
     '.groovy': {
         'class': AlitaTextLoader,
         'is_multimodal_processing': False,
         'kwargs': {
             'autodetect_encoding': True
-        }
+        },
+        'allowed_to_override': ['max_tokens']
     },
     '.md': {
-        'class': UnstructuredMarkdownLoader,
+        'class': AlitaMarkdownLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens']
     },
     '.csv': {
         'class': AlitaCSVLoader,
@@ -97,7 +115,8 @@ loaders_map = {
             'encoding': 'utf-8',
             'raw_content': False,
             'cleanse': False
-        }
+        },
+        'allowed_to_override': ['max_tokens']
     },
     '.xlsx': {
         'class': AlitaExcelLoader,
@@ -105,7 +124,8 @@ loaders_map = {
         'kwargs': {
             'raw_content': False,
             'cleanse': False
-        }
+        },
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.xls': {
         'class': AlitaExcelLoader,
@@ -113,57 +133,67 @@ loaders_map = {
         'kwargs': {
             'raw_content': False,
             'cleanse': False
-        }
+        },
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.pdf': {
         'class': AlitaPDFLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.docx': {
         'class': AlitaDocxMammothLoader,
         'is_multimodal_processing': True,
         'kwargs': {
             'extract_images': True
-        }
+        },
+        'allowed_to_override': ['max_tokens', 'mode', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.json': {
         'class': AlitaJSONLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens']
     },
     '.jsonl': {
         'class': AirbyteJSONLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens']
     },
     '.htm': {
         'class': UnstructuredHTMLLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.html': {
         'class': UnstructuredHTMLLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.ppt': {
         'class': AlitaPowerPointLoader,
         'is_multimodal_processing': False,
         'kwargs': {
             'mode': 'paged'
-        }
+        },
+        'allowed_to_override': ['max_tokens', 'mode', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.pptx': {
         'class': AlitaPowerPointLoader,
         'is_multimodal_processing': False,
         'kwargs': {
             'mode': 'paged'
-        }
+        },
+        'allowed_to_override': ['max_tokens', 'mode', LoaderProperties.LLM.value, LoaderProperties.PROMPT.value, LoaderProperties.PROMPT_DEFAULT.value]
     },
     '.py': {
-        'class': PythonLoader,
+        'class': AlitaPythonLoader,
         'is_multimodal_processing': False,
-        'kwargs': {}
+        'kwargs': {},
+        'allowed_to_override': ['max_tokens']
     }
 }
