@@ -1,4 +1,3 @@
-import base64
 import functools
 import json
 import logging
@@ -12,7 +11,8 @@ from langchain_core.documents import Document
 from langchain_core.tools import ToolException
 from pydantic import Field, PrivateAttr, create_model, model_validator, SecretStr
 
-from ..elitea_base import BaseVectorStoreToolApiWrapper, extend_with_vector_tools
+from ..non_code_indexer_toolkit import NonCodeIndexerToolkit
+from ..utils.available_tools_decorator import extend_with_parent_available_tools
 from ..utils.content_parser import load_content_from_bytes
 
 GLOBAL_LIMIT = 10000
@@ -229,47 +229,98 @@ class ArgsSchema(Enum):
     )
 
 
-class FigmaApiWrapper(BaseVectorStoreToolApiWrapper):
+class FigmaApiWrapper(NonCodeIndexerToolkit):
     token: Optional[SecretStr] = Field(default=None)
     oauth2: Optional[SecretStr] = Field(default=None)
     global_limit: Optional[int] = Field(default=GLOBAL_LIMIT)
     global_regexp: Optional[str] = Field(default=None)
     _client: Optional[FigmaPy] = PrivateAttr()
 
-    def _base_loader(self, project_id: Optional[str] = None, file_keys: Optional[List[str]] = None, **kwargs) -> Generator[Document, None, None]:
-        files = []
-        if project_id:
-            files = json.loads(self.get_project_files(project_id)).get('files', [])
-            for file in files:
-                yield Document(page_content=json.dumps(file), metadata={
-                    'id': file.get('key', ''),
-                    'file_key': file.get('key', ''),
-                    'name': file.get('name', ''),
-                    'updated_on': file.get('last_modified', '')
-                })
-        elif file_keys:
-            for file_key in file_keys:
+    def _base_loader(
+            self,
+            project_id: Optional[str] = None,
+            file_keys_include: Optional[List[str]] = None,
+            file_keys_exclude: Optional[List[str]] = None,
+            node_ids_include: Optional[List[str]] = None,
+            node_ids_exclude: Optional[List[str]] = None,
+            node_types_include: Optional[List[str]] = None,
+            node_types_exclude: Optional[List[str]] = None,
+            **kwargs
+    ) -> Generator[Document, None, None]:
+        # If both include and exclude are provided, use only include
+        if file_keys_include:
+            self._log_tool_event(f"Loading files: {file_keys_include}")
+            for file_key in file_keys_include:
+                self._log_tool_event(f"Loading file `{file_key}`")
                 file = self._client.get_file(file_key)
+                if not file:
+                    raise ToolException(f"Unexpected error while retrieving file {file_key}. Probably file is under editing. Try again later.")
                 metadata = {
                     'id': file_key,
                     'file_key': file_key,
                     'name': file.name,
-                    'updated_on': file.last_modified
+                    'updated_on': file.last_modified,
+                    'figma_pages_include': node_ids_include or [],
+                    'figma_pages_exclude': node_ids_exclude or [],
+                    'figma_nodes_include': node_types_include or [],
+                    'figma_nodes_exclude': node_types_exclude or []
                 }
                 yield Document(page_content=json.dumps(metadata), metadata=metadata)
+        elif project_id:
+            self._log_tool_event(f"Loading project files from project `{project_id}`")
+            files = json.loads(self.get_project_files(project_id)).get('files', [])
+            for file in files:
+                if file_keys_exclude and file.get('key', '') in file_keys_exclude:
+                    continue
+                yield Document(page_content=json.dumps(file), metadata={
+                    'id': file.get('key', ''),
+                    'file_key': file.get('key', ''),
+                    'name': file.get('name', ''),
+                    'updated_on': file.get('last_modified', ''),
+                    'figma_pages_include': node_ids_include or [],
+                    'figma_pages_exclude': node_ids_exclude or [],
+                    'figma_nodes_include': node_types_include or [],
+                    'figma_nodes_exclude': node_types_exclude or []
+                })
+        elif file_keys_exclude or node_ids_exclude:
+            raise ValueError("Excludes without parent (project_id or file_keys_include) do not make sense.")
+        else:
+            raise ValueError("You must provide at least project_id or file_keys_include.")
 
     def _process_document(self, document: Document) -> Generator[Document, None, None]:
         file_key = document.metadata.get('id', '')
+        self._log_tool_event(f"Loading details (images) for `{file_key}`")
         #
-        node_ids = []
-        children = self._client.get_file(file_key).document.get('children', [])
-        if children:
-            nodes = children[0].get('children', [])
-            node_ids = [node['id'] for node in nodes if 'id' in node]
-        images = self._client.get_file_images(file_key, node_ids).images or {}
+        figma_pages = self._client.get_file(file_key).document.get('children', [])
+        node_ids_include = document.metadata.pop('figma_pages_include', [])
+        node_ids_exclude = document.metadata.pop('figma_pages_exclude', [])
+        node_types_include = [t.lower() for t in document.metadata.pop('figma_nodes_include', [])]
+        node_types_exclude = [t.lower() for t in document.metadata.pop('figma_nodes_exclude', [])]
+        self._log_tool_event(f"Included pages: {node_ids_include}. Excluded pages: {node_ids_exclude}.")
+        if node_ids_include:
+            figma_pages = [node for node in figma_pages if ('id' in node and node['id'].replace(':', '-') in node_ids_include)]
+        elif node_ids_exclude:
+            figma_pages = [node for node in figma_pages if ('id' in node and node['id'].replace(':', '-') not in node_ids_exclude)]
+        node_ids = [
+            child['id']
+            for page in figma_pages
+            if 'children' in page
+            for child in page['children']
+            if 'id' in child
+            and (
+                (node_types_include and child.get('type').lower() in node_types_include)
+                or (node_types_exclude and child.get('type').lower() not in node_types_exclude)
+                or (not node_types_include and not node_types_exclude)
+            )
+        ]
 
-        # iterate over images values
-        for node_id, image_url in images.items():
+        images = self._client.get_file_images(file_key, node_ids).images or {}
+        total_images = len(images)
+        if total_images == 0:
+            logging.info(f"No images found for file {file_key}.")
+            return
+        progress_step = max(1, total_images // 10)
+        for idx, (node_id, image_url) in enumerate(images.items(), 1):
             if not image_url:
                 logging.warning(f"Image URL not found for node_id {node_id} in file {file_key}. Skipping.")
                 continue
@@ -280,24 +331,49 @@ class FigmaApiWrapper(BaseVectorStoreToolApiWrapper):
                     extension = f".{content_type.split('/')[-1]}" if content_type.startswith('image') else '.txt'
                     page_content = load_content_from_bytes(
                         file_content=response.content,
-                        extension=extension, llm = self.llm)
+                        extension=extension, llm=self.llm)
                     yield Document(
-                                    page_content=page_content,
-                                    metadata={
-                                        'file_key': file_key,
-                                        'node_id': node_id,
-                                        'image_url': image_url
-                                    }
-                                )
+                        page_content=page_content,
+                        metadata={
+                            'id': node_id,
+                            'updated_on': document.metadata.get('updated_on', ''),
+                            'file_key': file_key,
+                            'node_id': node_id,
+                            'image_url': image_url
+                        }
+                    )
+            if idx % progress_step == 0 or idx == total_images:
+                percent = int((idx / total_images) * 100)
+                msg = f"Processed {idx}/{total_images} images ({percent}%) for file {file_key}."
+                logging.info(msg)
+                self._log_tool_event(msg)
+
+    def _remove_metadata_keys(self):
+        return super()._remove_metadata_keys() + ['figma_pages_include', 'figma_pages_exclude', 'figma_nodes_include', 'figma_nodes_exclude']
 
     def _index_tool_params(self):
         """Return the parameters for indexing data."""
         return {
             "project_id": (Optional[str], Field(
-                description="ID of the project to list files from: i.e. '55391681'",
+                description="ID of the project to list files from: i.e. 55391681'",
                 default=None)),
-            'file_keys': (Optional[List[str]], Field(
-                description='List of file keys to index: i.e. ["Fp24FuzPwH0L74ODSrCnQo", "jmhAr6q78dJoMRqt48zisY"]',
+            'file_keys_include': (Optional[List[str]], Field(
+                description="List of file keys to include in index if project_id is not provided: i.e. ['Fp24FuzPwH0L74ODSrCnQo', 'jmhAr6q78dJoMRqt48zisY']",
+                default=None)),
+            'file_keys_exclude': (Optional[List[str]], Field(
+                description="List of file keys to exclude from index. It is applied only if project_id is provided and file_keys_include is not provided: i.e. ['Fp24FuzPwH0L74ODSrCnQo', 'jmhAr6q78dJoMRqt48zisY']",
+                default=None)),
+            'node_ids_include': (Optional[List[str]], Field(
+                description="List of top-level nodes (pages) in file to include in index. It is node-id from figma url: i.e. ['123-56', '7651-9230'].",
+                default=None)),
+            'node_ids_exclude': (Optional[List[str]], Field(
+                description="List of top-level nodes (pages) in file to exclude from index. It is applied only if node_ids_include is not provided. It is node-id from figma url: i.e. ['Fp24FuzPwH0L74ODSrCnQo', 'jmhAr6q78dJoMRqt48zisY']",
+                default=None)),
+            'node_types_include': (Optional[List[str]], Field(
+                description="List type of nodes to include in index: i.e. ['FRAME', 'COMPONENT', 'RECTANGLE', 'COMPONENT_SET', 'INSTANCE', 'VECTOR', ...].",
+                default=None)),
+            'node_types_exclude': (Optional[List[str]], Field(
+                description="List type of nodes to exclude from index. It is applied only if node_types_include is not provided: i.e. ['FRAME', 'COMPONENT', 'RECTANGLE', 'COMPONENT_SET', 'INSTANCE', 'VECTOR', ...]",
                 default=None))
         }
 
@@ -328,6 +404,11 @@ class FigmaApiWrapper(BaseVectorStoreToolApiWrapper):
             logging.error(msg)
             raise ToolException(msg)
 
+    @model_validator(mode='before')
+    @classmethod
+    def check_before(cls, values):
+        return super().validate_toolkit(values)
+
     @model_validator(mode="after")
     @classmethod
     def validate_toolkit(cls, values):
@@ -510,7 +591,7 @@ class FigmaApiWrapper(BaseVectorStoreToolApiWrapper):
         """Retrieves all files for a specified project ID from Figma."""
         return self._client.get_project_files(project_id)
 
-    @extend_with_vector_tools
+    @extend_with_parent_available_tools
     def get_available_tools(self):
         return [
             {
