@@ -2,12 +2,12 @@ import os
 import tempfile
 from logging import getLogger
 from pathlib import Path
-from typing import Generator
+from typing import Generator, List
 
 from langchain_core.documents import Document
 from langchain_core.tools import ToolException
 
-from alita_sdk.runtime.langchain.document_loaders.constants import loaders_map
+from alita_sdk.runtime.langchain.document_loaders.constants import loaders_map, LoaderProperties
 from ...runtime.utils.utils import IndexerKeywords
 
 logger = getLogger(__name__)
@@ -52,8 +52,6 @@ Highlight any visible details that could help in understanding the image.
 Be as precise and thorough as possible in your responses. If something is unclear or illegible, state that explicitly.
 '''
 
-IMAGE_EXTENSIONS = ['jpg', 'jpeg', 'png', 'gif', 'bmp', 'tiff', 'webp', 'svg']
-
 
 def parse_file_content(file_name=None, file_content=None, is_capture_image: bool = False, page_number: int = None,
                        sheet_name: str = None, llm=None, file_path: str = None, excel_by_sheets: bool = False) -> str | ToolException:
@@ -73,17 +71,56 @@ def parse_file_content(file_name=None, file_content=None, is_capture_image: bool
     Raises:
         ToolException: If the file type is not supported or if there is an error reading the file.
         """
+    loader = prepare_loader(
+        file_name=file_name,
+        file_content=file_content,
+        is_capture_image=is_capture_image,
+        page_number=page_number,
+        sheet_name=sheet_name,
+        llm=llm,
+        file_path=file_path,
+        excel_by_sheets=excel_by_sheets
+    )
 
-    if (file_path and (file_name or file_content)) or (not file_path and (not file_name or file_content is None)):
-        raise ToolException("Either (file_name and file_content) or file_path must be provided, but not both.")
-
-    extension = Path(file_path if file_path else file_name).suffix
-
-    loader_object = loaders_map.get(extension)
-    if not loader_object:
-        logger.warning(f"No loader found for file extension: {extension}. File: {file_path if file_path else file_name}")
+    if not loader:
         return ToolException(
             "Not supported type of files entered. Supported types are TXT, DOCX, PDF, PPTX, XLSX and XLS only.")
+
+    if hasattr(loader, 'get_content'):
+        return loader.get_content()
+    else:
+        extension = Path(file_path if file_path else file_name).suffix
+        loader_kwargs = get_loader_kwargs(loaders_map.get(extension), file_name, file_content, is_capture_image, page_number, sheet_name, llm, file_path, excel_by_sheets)
+        if file_content:
+            return load_content_from_bytes(file_content=file_content,
+                                           extension=extension,
+                                           loader_extra_config=loader_kwargs,
+                                           llm=llm)
+        else:
+            return load_content(file_path=file_path,
+                                extension=extension,
+                                loader_extra_config=loader_kwargs,
+                                llm=llm)
+
+def load_file_docs(file_name=None, file_content=None, is_capture_image: bool = False, page_number: int = None,
+                       sheet_name: str = None, llm=None, file_path: str = None, excel_by_sheets: bool = False) -> List[Document] | ToolException:
+    loader = prepare_loader(
+        file_name=file_name,
+        file_content=file_content,
+        is_capture_image=is_capture_image,
+        page_number=page_number,
+        sheet_name=sheet_name,
+        llm=llm,
+        file_path=file_path,
+        excel_by_sheets=excel_by_sheets
+    )
+    if not loader:
+        return ToolException(
+            "Not supported type of files entered. Supported types are TXT, DOCX, PDF, PPTX, XLSX and XLS only.")
+    return loader.load()
+
+def get_loader_kwargs(loader_object, file_name=None, file_content=None, is_capture_image: bool = False, page_number: int = None,
+                    sheet_name: str = None, llm=None, file_path: str = None, excel_by_sheets: bool = False):
     loader_kwargs = loader_object['kwargs']
     loader_kwargs.update({
         "file_path": file_path,
@@ -97,25 +134,21 @@ def parse_file_content(file_name=None, file_content=None, is_capture_image: bool
         "row_content": True,
         "json_documents": False
     })
-    loader = loader_object['class'](**loader_kwargs)
+    return loader_kwargs
 
-    if not loader:
-        return ToolException(
-            "Not supported type of files entered. Supported types are TXT, DOCX, PDF, PPTX, XLSX and XLS only.")
+def prepare_loader(file_name=None, file_content=None, is_capture_image: bool = False, page_number: int = None,
+                       sheet_name: str = None, llm=None, file_path: str = None, excel_by_sheets: bool = False):
+        if (file_path and (file_name or file_content)) or (not file_path and (not file_name or file_content is None)):
+            raise ToolException("Either (file_name and file_content) or file_path must be provided, but not both.")
 
-    if hasattr(loader, 'get_content'):
-        return loader.get_content()
-    else:
-        if file_content:
-            return load_content_from_bytes(file_content=file_content,
-                                           extension=extension,
-                                           loader_extra_config=loader_kwargs,
-                                           llm=llm)
-        else:
-            return load_content(file_path=file_path,
-                                extension=extension,
-                                loader_extra_config=loader_kwargs,
-                                llm=llm)
+        extension = Path(file_path if file_path else file_name).suffix
+
+        loader_object = loaders_map.get(extension)
+        if not loader_object:
+            return None
+        loader_kwargs = get_loader_kwargs(loader_object, file_name, file_content, is_capture_image, page_number, sheet_name, llm, file_path, excel_by_sheets)
+        loader = loader_object['class'](**loader_kwargs)
+        return loader
 
 # TODO: review usage of this function alongside with functions above
 def load_content(file_path: str, extension: str = None, loader_extra_config: dict = None, llm = None) -> str:
@@ -168,7 +201,7 @@ def load_content_from_bytes(file_content: bytes, extension: str = None, loader_e
         if temp_file_path and os.path.exists(temp_file_path):
             os.remove(temp_file_path)
 
-def process_content_by_type(document: Document, content, extension_source: str, llm = None, chunking_config={}) -> Generator[Document, None, None]:
+def process_content_by_type(document: Document, content, extension_source: str, llm = None, chunking_config=None) -> Generator[Document, None, None]:
     temp_file_path = None
     try:
         extension = "." + extension_source.split('.')[-1].lower()
@@ -189,9 +222,33 @@ def process_content_by_type(document: Document, content, extension_source: str,
 
             loader_cls = loader_config['class']
             loader_kwargs = loader_config['kwargs']
-
+            # Determine which loader configuration keys are allowed to be overridden by user input.
+            # If 'allowed_to_override' is specified in the loader configuration, use it; otherwise, allow all keys in loader_kwargs.
+            allowed_to_override = loader_config.get('allowed_to_override', list(loader_kwargs.keys()))
+            # If a chunking_config is provided and contains custom configuration for the current file extension,
+            # update loader_kwargs with user-supplied values, but only for keys explicitly permitted in allowed_to_override.
+            # This ensures that only safe and intended parameters can be customized, preventing accidental or unauthorized changes
+            # to critical loader settings.
+            if chunking_config and (users_config_for_extension := chunking_config.get(extension, {})):
+                for key in set(users_config_for_extension.keys()) & set(allowed_to_override):
+                    loader_kwargs[key] = users_config_for_extension[key]
+            if LoaderProperties.LLM.value in loader_kwargs:
+                loader_kwargs[LoaderProperties.LLM.value] = llm
+            if LoaderProperties.PROMPT_DEFAULT.value in loader_kwargs:
+                loader_kwargs.pop(LoaderProperties.PROMPT_DEFAULT.value)
+                loader_kwargs[LoaderProperties.PROMPT.value] = image_processing_prompt
             loader = loader_cls(file_path=temp_file_path, **loader_kwargs)
-            for chunk in loader.load():
+            try:
+                chunks = loader.load()
+            except Exception as e:
+                msg = f"Error during content for file {temp_file_path}:\n{e}"
+                logger.warning(msg)
+                yield Document(
+                    page_content=msg,
+                    metadata={**document.metadata, 'chunk_id':1}
+                )
+                return
+            for chunk in chunks:
                 yield Document(
                     page_content=sanitize_for_postgres(chunk.page_content),
                     metadata={**document.metadata, **chunk.metadata}
