@@ -1216,7 +1216,7 @@ class ZephyrScaleApiWrapper(NonCodeIndexerToolkit):
             Example:
                 'folder = "Authentication" AND label in ("Smoke", "Critical") AND text ~ "login" AND orderBy = "name" AND orderDirection = "ASC"'
             """)),
-            'chunking_tool': (Literal['json'], Field(description="Name of chunking tool", default='json'))
+            'chunking_tool': (Literal['json', ''], Field(description="Name of chunking tool", default='json'))
         }
 
     def _base_loader(self, project_key: str, jql: str, **kwargs) -> Generator[Document, None, None]:
@@ -1289,8 +1289,6 @@ class ZephyrScaleApiWrapper(NonCodeIndexerToolkit):
                         if content:
                             page_content = json.dumps(content)
                             document.metadata[IndexerKeywords.CONTENT_IN_BYTES.value] = page_content.encode('utf-8')
-                            document.metadata[
-                                IndexerKeywords.CONTENT_FILE_NAME.value] = f"base_doc{file_extension_by_chunker(self._chunking_tool)}"
                             document.metadata["steps_type"] = steps_type
             except Exception as e:
                 logging.error(f"Failed to process document: {e}")
